@@ -5,11 +5,11 @@ setAs('data.frame', 'SpatialPolygons',
 		obs <- unique(from$object)
 		sp <- list()
 		for (i in 1:length(obs)) {
-			s <- subset(from, object==obs[i])
+			s <- from[from$object==obs[i], ]
 			p <- unique(s$part)
 			pp <- list()
 			for (j in 1:length(p)) {
-				ss <- subset(s, part==p[j])
+				ss <- s[s$part==p[j], ]
 				pol <- Polygon(as.matrix(ss)[,5:6])
 				if (ss$hole[1]) {
 					pol@hole <- TRUE
@@ -28,7 +28,7 @@ setAs('data.frame', 'SpatialPolygonsDataFrame',
 	function(from) {
 		x <- as(from, 'SpatialPolygons')
 		if (ncol(from) > 6) {
-			d <- unique(pts[, -c(3:6), drop=FALSE])
+			d <- unique(from[, -c(3:6), drop=FALSE])
 			rownames(d) <- d$object
 			SpatialPolygonsDataFrame(x, d)
 		} else {
