@@ -6,7 +6,7 @@
 # Licence GPL v3
 
 
-.zipKML <- function(kml, image, zip) {
+.zipKML <- function(kml, image, zip, overwrite=FALSE) {
 	if (zip == "") {
 		zip <- Sys.getenv('R_ZIPCMD', 'zip')
 	}
@@ -16,10 +16,16 @@
 		setwd(dirname(kml))
 		kml <- basename(kml)
 		kmz <- extension(kml, '.kmz')
-		image <- basename(image)
+		
 		if (file.exists(kmz)) {
-			x <- file.remove(kmz)
-		}
+			if (overwrite) {
+				file.remove(kmz)
+			} else {
+				stop('kml file created, but kmz file exists, use "overwrite=TRUE" to overwrite it')
+			}
+		}	
+		
+		image <- basename(image)
 		if (zip=='7z') {
 			kmzzip <- extension(kmz, '.zip')
 			cmd <- paste(zip, 'a', kmzzip, kml, image, collapse=" ")
@@ -29,7 +35,9 @@
 		}
 		sss <- try( system(cmd, intern=TRUE), silent=TRUE )
 		if (file.exists(kmz)) {
-			x <- file.remove(kml, image)
+			files <- c(kml, image)
+			files <- files[file.exists(files)]
+			x <- file.remove(files)
 			return(invisible(kmz))
 		} else {
 			return(invisible(kml))
@@ -42,7 +50,7 @@
 
 setMethod('KML', signature(x='RasterStackBrick'), 
 
-function (x, filename, time=NULL, col=rev(terrain.colors(255)), colNA=NA, maxpixels=100000, blur=1, zip='', ...) {
+function (x, filename, time=NULL, col=rev(terrain.colors(255)), colNA=NA, maxpixels=100000, blur=1, zip='', overwrite=FALSE, ...) {
 
     if (! .couldBeLonLat(x)) { 
         stop("CRS of x must be longitude/latitude")
@@ -70,6 +78,14 @@ function (x, filename, time=NULL, col=rev(terrain.colors(255)), colNA=NA, maxpix
 	x <- sampleRegular(x, size=maxpixels, asRaster = TRUE, useGDAL=TRUE)
 	kmlfile <- filename
 	extension(kmlfile) <- '.kml'
+	if (file.exists(kmlfile)) {
+		if (overwrite) {
+			file.remove(kmlfile)
+		} else {
+			stop('kml file exists, use "overwrite=TRUE" to overwrite it')
+		}
+	}	
+	
 	
 	name <- names(x)
 
@@ -83,7 +99,7 @@ function (x, filename, time=NULL, col=rev(terrain.colors(255)), colNA=NA, maxpix
 	
 	
 	for (i in 1:nl) {
-		png(filename = imagefile, width=max(480, blur*ncol(x)), height=max(480,blur*nrow(x)), bg="transparent")
+		png(filename = imagefile[i], width=max(480, blur*ncol(x)), height=max(480,blur*nrow(x)), bg="transparent")
 		if (!is.na(colNA)) {
 			par(mar=c(0,0,0,0), bg=colNA)
 		} else {
@@ -110,7 +126,7 @@ function (x, filename, time=NULL, col=rev(terrain.colors(255)), colNA=NA, maxpix
 
     kml <- c(kml, "</Folder>", "</kml>")
     cat(paste(kml, sep="", collapse="\n"), file=kmlfile, sep = "")
-	raster:::.zipKML(kmlfile, imagefile, zip)
+	.zipKML(kmlfile, imagefile, zip, overwrite=overwrite)
 }
 )
 
